import 'package:get/get.dart';
import 'package:mypoint_flutter_app/networking/restful_api_request.dart';
import '../../base/restful_api_viewmodel.dart';
import '../../preference/data_preference.dart';
import 'models/category_notify_item_model.dart';
import 'models/notification_item_model.dart';

class NotificationViewModel extends RestfulApiViewModel {
  var categories = RxList<CategoryNotifyItemModel>();
  var notifications = RxList<NotificationItemModel>();
  final RxBool isLoading = false.obs;

  CategoryNotifyItemModel? get selectedCategory =>
      categories.isNotEmpty ? categories.firstWhere((item) => item.isSelected ?? false) : null;
  
  @override
  void onInit() {
    super.onInit();
    _fetchCategories();
  }

  void _fetchCategories() async {
    showLoading();
    client.getNotificationCategories().then((value) {
      final results = value.data ?? [];
      if (results.isNotEmpty) {
        results[0].isSelected = true;
      }
      categories.value = results;
      fetchNotifications(refresh: true);
    });
  }

  void fetchNotifications({bool refresh = false}) async {
    if (isLoading.value) return;
    isLoading.value = true;
    String? token = DataPreference.instance.token ?? "";
    final body = {
      "access_token": token,
      "start": refresh ? 0 : notifications.length,
      "limit": 10,
      "noti_group_id": selectedCategory?.id ?? "",
    };
    client.getNotifications(body).then((value) {
      isLoading.value = false;
      hideLoading();
      if (refresh) {
        notifications.value = value.data?.items ?? [];
      } else {
        notifications.addAll(value.data?.items ?? []);
      }
    });
  }

  void selectCategory(int index) {
    for (var i = 0; i < categories.length; i++) {
      categories[i].isSelected = i == index;
    }
    fetchNotifications(refresh: true);
  }

  notificationMarkAsSeen() {
    client.notificationMarkAsSeen().then((value) {
      _fetchCategories();
    });
  }

  deleteAllNotifications() {
    client.deleteAllNotifications().then((value) {
      _fetchCategories();
    });
  }
}
